@@ -18,6 +18,8 @@
 # along with Auto-Multiple-Choice.  If not, see
 # <http://www.gnu.org/licenses/>.
 
+use encoding "utf-8";
+
 use XML::Simple;
 use File::Copy;
 use File::Spec::Functions qw/splitpath catpath splitdir catdir catfile rel2abs tmpdir/;
@@ -259,13 +261,13 @@ sub execute {
 
     if($format eq 'dvi') {
 	if(-f $f_base.".dvi") {
-	    system("dvips","-q",$f_base,"-o",$f_base.".ps");
-	    print "Error dvips : $?\n" if($?);
-	    if(-f $f_base.".ps") {
-		system("ps2pdf",$f_base.".ps",$f_base.".pdf");
-		print "Error ps2pdf : $?\n" if($?);
+	    if(commande_accessible('dvipdfm')) {
+		debug "Converting DVI to PDF with dvipdfm...";
+		system("dvipdfm","-o",$f_base.".pdf",$f_base.".dvi");
+		print "ERROR dvipdfm: $?\n" if($?);
 	    } else {
-		debug "No PS";
+		print "ERROR: I can't find dvipdfm command !";
+		debug "ERROR: I can't find dvipdfm command !";
 	    }
 	} else {
 	    debug "No DVI";
